KFAnalyticsEvent class

KwikForms Analytics Event Configuration Maps property names to actual event name strings (fallback values)

Constructors

KFAnalyticsEvent()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

KF_AUTOFILLED_FILL → const String
KF_FORM_VIEWED → const String
KF_LOADED → const String
KF_OTP → const String
KF_OTP_VERIFIED → const String
KF_POPUP_DISMISSED → const String
KF_QR_SCANNED → const String
KF_SSO → const String
KF_SSO_SUCCESS → const String
KF_SUBMITTED → const String
values → const Map<String, String>