RemoteKey class

Remote Key Configuration Real values are delivered via CDN; local fallback is empty string.

Constructors

RemoteKey()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

googleMapsKey → const String
values → const Map<String, String>