SecureStorage class

Constructors

SecureStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearAllSecureData() → Future<void>
✅ Clear all stored keys in SharedPreferences
clearSecureData(String key) → Future<void>
getSecureData(String key) → Future<String?>
init() → Future<void>
storeSecureData(String key, String value) → Future<void>