CheckoutShopifyProps class

Implementers

Constructors

CheckoutShopifyProps({String? cartId, String? storefrontToken, String? storeId, String? fbPixel, String? gaTrackingID, String? webEngageID, String? moEngageID, String? sessionId, Map<String, String>? utmParams, String? orderTags, String? discountCodes})

Properties

cartId String?
final
discountCodes String?
final
fbPixel String?
final
gaTrackingID String?
final
hashCode int
The hash code for this object.
no setterinherited
moEngageID String?
final
orderTags String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
storefrontToken String?
final
storeId String?
final
utmParams Map<String, String>?
final
webEngageID String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited