InitializeSdkProps class
Constructors
-
InitializeSdkProps({required String mid, required Environment environment, String? shopDomain, bool? isSnowplowTrackingEnabled, required MerchantType merchantType, String? kcMerchantId, String? kcMerchantToken, String? mode, Settings? settings, String? moEngageId, void onAnalytics(String eventName, Map<
String, dynamic> properties)?})
Properties
- environment → Environment
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSnowplowTrackingEnabled ↔ bool?
-
getter/setter pair
- kcMerchantId ↔ String?
-
getter/setter pair
- kcMerchantToken ↔ String?
-
getter/setter pair
- merchantType ↔ MerchantType
-
getter/setter pair
- mid → String
-
final
- mode ↔ String?
-
getter/setter pair
- moEngageId ↔ String?
-
getter/setter pair
-
onAnalytics
↔ void Function(String eventName, Map<
String, dynamic> properties)? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings ↔ Settings?
-
getter/setter pair
- shopDomain ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited