KPCheckoutProps class

Constructors

KPCheckoutProps({CheckoutData? checkoutData, dynamic onEvent(dynamic)?, dynamic onError(dynamic)?})

Properties

checkoutData → CheckoutData?
final
hashCode → int
The hash code for this object.
no setterinherited
onError → dynamic Function(dynamic)?
final
onEvent → dynamic Function(dynamic)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited