KwikPassConfig class

Constructors

KwikPassConfig({required String mid, required Environment environment, required MerchantType merchantType, bool? enabled, String? shopDomain, bool? isSnowplowTrackingEnabled, String? kcMerchantId, String? kcMerchantToken})

Properties

enabled bool?
final
environment Environment
final
hashCode int
The hash code for this object.
no setterinherited
isSnowplowTrackingEnabled bool?
getter/setter pair
kcMerchantId String?
getter/setter pair
kcMerchantToken String?
getter/setter pair
merchantType MerchantType
final
mid String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shopDomain String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited