MerchantConfig class

Constructors

MerchantConfig({required int id, required String merchantId, required String name, required String host, required String platform, required bool kwikpassEnabled, required bool isWhatsappOtpLessActive, required bool isTruecallerActive, required String integrationType, required bool isLogoutBtnDisabled, required String popupBreakpoint, required String apiKey, required bool isPublicAppInstalled, required List<ThirdPartyServiceProvider> thirdPartyServiceProviders, required String kpRequestId, required bool customerIntelligenceEnabled, required dynamic customerIntelligenceMetrics, required String marketingPopupGlobalLimit, required String customerAccountsVersion, required bool rlEnabled, String? kpAppName, bool isCustomAccountPageEnabled = false, bool isPagePingEnabled = false, dynamic pagePingConfig, List<String> kpFeatures = const [], String? consentState, bool isDPDPCompliancePopup = false, bool isSilentAuth = false, bool isCustomizePopupHandled = false, bool isMultiplePlatform = false, bool isS2sEventEnabled = false, Map<String, dynamic>? merchantIntegrationType})
MerchantConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiKey String
final
consentState String?
final
customerAccountsVersion String
final
customerIntelligenceEnabled bool
final
customerIntelligenceMetrics → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
host String
final
id int
final
integrationType String
final
isCustomAccountPageEnabled bool
final
isCustomizePopupHandled bool
final
isDPDPCompliancePopup bool
final
isLogoutBtnDisabled bool
final
isMultiplePlatform bool
final
isPagePingEnabled bool
final
isPublicAppInstalled bool
final
isS2sEventEnabled bool
final
isSilentAuth bool
final
isTruecallerActive bool
final
isWhatsappOtpLessActive bool
final
kpAppName String?
final
kpFeatures List<String>
final
kpRequestId String
final
kwikpassEnabled bool
final
marketingPopupGlobalLimit String
final
merchantId String
final
merchantIntegrationType Map<String, dynamic>?
final
name String
final
pagePingConfig → dynamic
final
platform String
final
popupBreakpoint String
final
rlEnabled bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thirdPartyServiceProviders List<ThirdPartyServiceProvider>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited