ShopifyVerifyCodeData class

Constructors

ShopifyVerifyCodeData({dynamic affluence, required String email, String? phone, required bool isNewUser, String? token, String? coreToken, String? kpToken, String? shopifyCustomerId, String? state, String? accountActivationUrl})

Properties

accountActivationUrl → String?
final
affluence → dynamic
final
coreToken → String?
final
email → String
final
hashCode → int
The hash code for this object.
no setterinherited
isNewUser → bool
final
kpToken → String?
final
phone → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopifyCustomerId → String?
final
state → String?
final
token → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited