TrackCollectionEventContext class

Constructors

TrackCollectionEventContext({required String collection_id, String? img_url, required String collection_name, required String collection_handle, required String type})
TrackCollectionEventContext.fromJson(Map<String, dynamic> json)
factory

Properties

collection_handle → String
final
collection_id → String
final
collection_name → String
final
hashCode → int
The hash code for this object.
no setterinherited
img_url → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited