TrackContentInteractionEventArgs class

Constructors

TrackContentInteractionEventArgs({required String contentId, required String interactionType, required String contentType, String? contentTitle, String? contentUrl, int? durationWatched})

Properties

contentId String
final
contentTitle String?
final
contentType String
final
contentUrl String?
final
durationWatched int?
final
hashCode int
The hash code for this object.
no setterinherited
interactionType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited