TrackCustomAppEventArgs class
Constructors
-
TrackCustomAppEventArgs({required String category, required String action, String? label, List<
CustomEventProperty> ? properties})
Properties
- action → String
-
final
- category → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
-
properties
→ List<
CustomEventProperty> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited