TrackSearchEventArgs class

Constructors

TrackSearchEventArgs({required String query, int? resultsCount, String? searchType, String? collectionId})

Properties

collectionId String?
final
hashCode int
The hash code for this object.
no setterinherited
query String
final
resultsCount int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchType String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited