KFSubmittedPayload class

Constructors

KFSubmittedPayload({required String phone, required bool consent, required List<String> modifiedPrefillFieldIds, required List<String> allNonPhoneFieldIds, required int kpStandardFieldCount})
const

Properties

allNonPhoneFieldIds List<String>
final
final
hashCode int
The hash code for this object.
no setterinherited
kpStandardFieldCount int
final
modifiedPrefillFieldIds List<String>
final
phone String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited