KfFormScreen class

Constructors

KfFormScreen({required String title, required String subTitle, required String buttonText, required List<KfInputField> inputFields})
const
KfFormScreen.fromJson(Map<String, dynamic> json)
factory

Properties

buttonText String
final
hashCode int
The hash code for this object.
no setterinherited
inputFields List<KfInputField>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTitle String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited