KfInputField class

Constructors

KfInputField({required String id, required String type, required String label, bool required = false, List<String> options = const [], bool isKpStandard = false})
const
KfInputField.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isKpStandard bool
final
label String
final
options List<String>
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited