KfSuccessScreen class

Constructors

KfSuccessScreen({required String heading, required String message, required int screenTimeout})
const
KfSuccessScreen.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
heading String
final
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenTimeout int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited