KwikAddressCoordinates class

Constructors

KwikAddressCoordinates({required double lat, required double lng, String? source})
const
KwikAddressCoordinates.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lat double
final
lng double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
'google' for geocoded/map-picked, 'gokwik' for network addresses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited