mapPickedAddress property
Address pre-filled from a map selection by the host app. When this changes to a non-null value, the widget navigates to the Add Address screen with fields pre-populated.
Implementation
final KwikAddress? mapPickedAddress;
Address pre-filled from a map selection by the host app. When this changes to a non-null value, the widget navigates to the Add Address screen with fields pre-populated.
final KwikAddress? mapPickedAddress;