onSubmissionFailed property
Called when the address submission API call fails. Receives the error for the host app to handle (e.g. show a toast).
Implementation
final ValueChanged<dynamic>? onSubmissionFailed;
Called when the address submission API call fails. Receives the error for the host app to handle (e.g. show a toast).
final ValueChanged<dynamic>? onSubmissionFailed;