KwikFormsStandaloneConfig class

Standalone mode: host provides user credentials, login screen is bypassed.

Inheritance

Constructors

KwikFormsStandaloneConfig({required String phone, required String authToken, String? email})
const

Properties

authToken String
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
phone String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited