fieldHints property
Per-field placeholder/hint overrides, keyed by KfInputField.id. When absent, the field label is used as the hint (current behaviour).
Implementation
final Map<String, String>? fieldHints;
Per-field placeholder/hint overrides, keyed by KfInputField.id. When absent, the field label is used as the hint (current behaviour).
final Map<String, String>? fieldHints;