mapAddressSubtitle property

String? mapAddressSubtitle
final

Subtitle shown below the title on the Add Address screen when the address originates from a map selection. Default: "Pre-filled from your map selection. Edit if needed."

Implementation

final String? mapAddressSubtitle;