mapPinnedChipText property
Text label inside the "Location pinned from map" chip shown when address originates from a map selection. Default: "Location pinned from map".
Implementation
final String? mapPinnedChipText;
Text label inside the "Location pinned from map" chip shown when address originates from a map selection. Default: "Location pinned from map".
final String? mapPinnedChipText;