KwikLoginConfig class

Full customisation config for the login step inside KwikForms. Mirrors every prop accepted by GoKwikLoginAndSignUpFlow so the host app has the same degree of control as when embedding the login flow standalone.

Constructors

KwikLoginConfig({dynamic onSuccess(FlowResult)?, dynamic onError(FlowResult)?, void onAnalytics(String, Map<String, dynamic>)?, ImageProvider<Object>? bannerImage, BoxDecoration? bannerImageStyle, BoxDecoration? logoStyle, BoxDecoration? containerStyle, BoxDecoration? formContainerStyle, BoxDecoration? imageContainerStyle, TextInputConfig? inputProps, CreateUserConfig? createUserConfig, LoadingConfig? loaderConfig, String? footerText, List<FooterUrl>? footerUrls, TextStyle? footerTextStyle, TextStyle? footerHyperlinkStyle, bool enableGuestLogin = false, String guestLoginButtonLabel = 'Skip', VoidCallback? onGuestLoginPress, BoxDecoration? guestContainerStyle, TextStyle? guestLoginTextStyle, MerchantType? merchantType})
const

Properties

bannerImage ImageProvider<Object>?
final
bannerImageStyle BoxDecoration?
final
containerStyle BoxDecoration?
final
createUserConfig CreateUserConfig?
final
enableGuestLogin bool
final
footerHyperlinkStyle TextStyle?
final
footerText String?
final
footerTextStyle TextStyle?
final
footerUrls List<FooterUrl>?
final
formContainerStyle BoxDecoration?
final
guestContainerStyle BoxDecoration?
final
guestLoginButtonLabel String
final
guestLoginTextStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
imageContainerStyle BoxDecoration?
final
inputProps TextInputConfig?
final
loaderConfig LoadingConfig?
final
final
logoStyle BoxDecoration?
final
merchantType MerchantType?
final
onAnalytics → void Function(String, Map<String, dynamic>)?
final
onError → dynamic Function(FlowResult)?
final
onGuestLoginPress VoidCallback?
final
onSuccess → dynamic Function(FlowResult)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited