NotificationHelper class

Constructors

NotificationHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkAndRequestUserPermission() → Future<bool>
sendNotificationStatus(String messageId, String status, {String failureReason = '', String buttonId = ''}) → Future<void>
sendOptInStatus(bool status) → Future<void>