CreateAccountForm class

Constructors

CreateAccountForm({String email = '', String username = '', String gender = '', DateTime? dob})

Properties

dob ↔ DateTime?
getter/setter pair
email ↔ String
getter/setter pair
gender ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited