GoKwikLoginAndSignUpFlow class

Inheritance

Constructors

GoKwikLoginAndSignUpFlow({Key? key, ImageProvider<Object>? bannerImage, BoxDecoration? bannerImageStyle, BoxDecoration? logoStyle, BoxDecoration? containerStyle, BoxDecoration? formContainerStyle, BoxDecoration? imageContainerStyle, LoadingConfig? loaderConfig, String? footerText, List<FooterUrl>? footerUrls, TextStyle? footerTextStyle, TextStyle? footerHyperlinkStyle, dynamic onSuccess(FlowResult)?, dynamic onError(FlowResult)?, void onAnalytics(String eventName, Map<String, dynamic> properties)?, void onOtpSent(String phone)?, void onOtpVerified(String phone)?, CreateUserConfig? createUserConfig, bool enableGuestLogin = false, String guestLoginButtonLabel = 'Skip', VoidCallback? onGuestLoginPress, BoxDecoration? guestContainerStyle, TextInputConfig? inputProps, MerchantType? merchantType, TextStyle? guesLoginTextStyle})
const

Properties

bannerImage → ImageProvider<Object>?
final
bannerImageStyle → BoxDecoration?
final
containerStyle → BoxDecoration?
final
createUserConfig → CreateUserConfig?
final
enableGuestLogin → bool
final
footerHyperlinkStyle → TextStyle?
final
footerText → String?
final
footerTextStyle → TextStyle?
final
footerUrls → List<FooterUrl>?
final
formContainerStyle → BoxDecoration?
final
guesLoginTextStyle → TextStyle?
final
guestContainerStyle → BoxDecoration?
final
guestLoginButtonLabel → String
final
hashCode → int
The hash code for this object.
no setterinherited
imageContainerStyle → BoxDecoration?
final
inputProps → TextInputConfig?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loaderConfig → LoadingConfig?
final
final
logoStyle → BoxDecoration?
final
merchantType → MerchantType?
final
onAnalytics → void Function(String eventName, Map<String, dynamic> properties)?
final
onError → dynamic Function(FlowResult)?
final
onGuestLoginPress → VoidCallback?
final
onOtpSent → void Function(String phone)?
final
onOtpVerified → void Function(String phone)?
final
onSuccess → dynamic Function(FlowResult)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited