ApiService class abstract

Constructors

ApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

activateUserAccount(String id, String url, String password, String token) Future<Result>
addAddress(Map<String, dynamic> body) Future<Result>
checkKwikpassHealth() Future<Result<HealthCheckResponseData?>>
clearKwikpassSession() Future<bool>
createUserApi({required String email, required String name, String? dob, String? gender}) Future<Result<Map<String, dynamic>?>>
customerIntelligence() Future<Result>
getAddressByPhone(String phone) Future<Result>
getBrowserToken() Future<Result>
getGeoInfo(String pincode) Future<Result>
getHostName(String url) String
getKfAssetsProperties() Future<Result>
getKwikFormData() Future<Result>
handleApiError(dynamic error) Failure
initializeMerchant(String mid, String environment) Future<Result<MerchantConfig?>>
initializeSdk(InitializeSdkProps args) Future<Map<String, dynamic>>
kwikpassLoginWithToken({required String token, required String phone, required String email, required String shopifyCustomerId}) Future<Result<Map<String, dynamic>>>
loginKpUser() Future<Result<LoginResponseData?>>
sendGoogleAdIdentification() Future<Result>
sendVerificationCode(String phoneNumber, bool notifications) Future<Result<OtpSentResponseData?>>
submitKwikFormData({required String phone, required String countryCode, required String address, required String name, required String gender, required String firstName, required String lastName, required String email, required bool consent}) Future<Result>
validateUserToken() Future<Result<String>>
verifyCode(String phoneNumber, String code) Future<Result>