SnowplowClient class abstract

Constructors

SnowplowClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getSnowplowClient({String? mid, Environment? environment, String? merchantType}) Future<SnowplowTracker?>
initializeSnowplowClient({required String mid, required Environment environment, String merchantType = 'shopify'}) Future<void>