InitializeSdkProps class
Constructors
- InitializeSdkProps({KwikPassConfig? kwikpassConfig, CheckoutConfig? checkoutConfig, String? mode, Function? onAnalytics})
Properties
- checkoutConfig → CheckoutConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kwikpassConfig → KwikPassConfig?
-
final
- mode ↔ String?
-
getter/setter pair
- onAnalytics ↔ Function?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited