KfAssetsConfig class
Constructors
- KfAssetsConfig({required String primaryColour, required KfFormScreen formScreen, required KfAddressScreen addressScreen, required KfSuccessScreen successScreen})
-
const
Properties
- addressScreen → KfAddressScreen
-
final
- formScreen → KfFormScreen
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryColor → Color
-
no setter
- primaryColour → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successScreen → KfSuccessScreen
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromApiResponse(
dynamic apiResponse) → KfAssetsConfig? - Parses the raw API response from getKfAssetsProperties. Expects: data.components.LEAD_GENE_POPUP.properties